package com.oqpo.api.web.dto.response.stinfo.itemUnit;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.oqpo.api.web.dto.request.stinfo.item.SaveItemListData;
import com.oqpo.api.web.dto.request.stinfo.itemUnit.SaveContractListData;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;

import java.util.List;
import java.util.stream.Collectors;

@Getter
@Setter
@Builder
@AllArgsConstructor(access = AccessLevel.PROTECTED)
@JsonInclude(JsonInclude.Include.ALWAYS)
public class ChkUploadContractListResponse {

    @ApiModelProperty(value = "성공건수")
    private int successCnt;

    @ApiModelProperty(value = "실패건수")
    private int errorCnt;

    @ApiModelProperty(value = "단가 리스트")
    private List<ChkContractListData> itemList;


    public static ChkUploadContractListResponse toDTO(int success, int error, List<SaveContractListData> entities) {
        if (entities == null) return null;

        return ChkUploadContractListResponse.builder()
                .successCnt(success)
                .errorCnt(error)
                .itemList(entities.stream()
                        .map(m -> ChkContractListData.builder()
                                .viewCd("C")
                                .resultCd(m.getResultCd())
                                .resultMsg(m.getResultMsg())
                                .itemId(m.getItemId())
                                .itemNm(m.getItemNm())
                                .spplyId(m.getSpplyId())
                                .spplyNm(m.getSpplyNm())
                                .contSttDt(m.getContSttDt())
                                .contEndDt(m.getContEndDt())
                                .curr(m.getCurr())
                                .unitAmt(m.getUnitAmt())
                                .leadTime(m.getLeadTime())
                                .storeSaleUnitAmt(m.getStoreSaleUnitAmt())
                                .build())
                        .collect(Collectors.toList()))
                .build();
    }

    @Getter
    @Builder
    @AllArgsConstructor(access = AccessLevel.PROTECTED)
    static class ChkContractListData {

        @ApiModelProperty(value = "CRUD")
        private String viewCd;

        @ApiModelProperty(value = "결과코드")
        private String resultCd;

        @ApiModelProperty(value = "결과명")
        private String resultMsg;

        @ApiModelProperty(value = "품목아이디")
        private String itemId;

        @ApiModelProperty(value = "품목명")
        private String itemNm;

        @ApiModelProperty(value = "공급사아이디")
        private String spplyId;

        @ApiModelProperty(value = "공급사명")
        private String spplyNm;

        @ApiModelProperty(value = "계약시작일")
        private String contSttDt;

        @ApiModelProperty(value = "계약종료일")
        private String contEndDt;

        @ApiModelProperty(value = "통화")
        private String curr;

        @ApiModelProperty(value = "단가")
        private String unitAmt;

        @ApiModelProperty(value = "리드타임")
        private String leadTime;

        @ApiModelProperty(value = "매장판매단가")
        private String storeSaleUnitAmt;

    }
}
